import java.util.HashMap;

/**
 * Class Room - a room in an adventure game.
 *
 * This class is part of the "World of Zuul" application. 
 * "World of Zuul" is a very simple, text based adventure game.  
 *
 * A "Room" represents one location in the scenery of the game.  It is 
 * connected to other rooms via exits.  The exits are labelled north, 
 * east, south, west.  For each direction, the room stores a reference
 * to the neighboring room, or null if there is no exit in that direction.
 * 
 * @author  Michael Kolling and David J. Barnes
 * @version 2008.03.30
 */
public class Room 
{
	//enum Direction {north, south, east, west}
    private String description;
//    public Room northExit;
//    public Room southExit;
//    public Room eastExit;
//    public Room westExit;
    private HashMap<Direction, Room> exits = new HashMap<Direction, Room>();
    

    /**
     * Create a room described "description". Initially, it has
     * no exits. "description" is something like "a kitchen" or
     * "an open court yard".
     * @param description The room's description.
     */
    public Room(String description) 
    {
        this.description = description;
    }

    /**
     * Define the exits of this room.  Every direction either leads
     * to another room or is null (no exit there).
     * @param dir - direction of exit
     * @param exit - Room to exit to
     */
    public void setExit(Direction dir, Room exit) 
    {
        	exits.put(dir, exit);
    }
    
    public Room getExit(Direction dir) {
    		return exits.get(dir);
    }
    
    public void printExits() {
    		for (Direction dir : exits.keySet())
    			System.out.print(dir + " ");
    }

    /**
     * @return The description of the room.
     */
    public String getDescription()
    {
        return description;
    }

}
